@@ -2,6 +2,7 @@ use super::commands::SubscribeCommand;
 use super::command_results::SubscribeCommandResult;
 use super::queries::LoginQuery;
 use super::query_results::LoginQueryResult;
+use log::info;
 
 
 pub trait QueryHandler<T> { 
@@ -24,7 +25,7 @@ impl SubscribeCommandHandler {
 
 impl CommandHandler<SubscribeCommandResult> for SubscribeCommandHandler { 
      fn execute(&self) -> Result<SubscribeCommandResult, std::io::Error> { 
-        println!("executing");
+        info!("executing");
         Ok(SubscribeCommandResult{})
     }
 }
@@ -41,7 +42,7 @@ impl LoginQueryHandler {
 
 impl QueryHandler<LoginQueryResult> for LoginQueryHandler { 
     fn retrieve(&self) -> Result<LoginQueryResult, std::io::Error> { 
-        println!("retrieving");
+        info!("retrieving");
         Ok(LoginQueryResult{})
     }
 }
